==> cotrix-web-publish-0.2.0-20140629.003540-5.jar: org/cotrix/web/publish/client/PublishServiceAsync.java <==
package org.cotrix.web.publish.client;

import com.google.gwt.core.client.GWT;
import com.google.gwt.user.client.rpc.AsyncCallback;

public interface PublishServiceAsync
{

    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getCodelists( com.google.gwt.view.client.Range range, org.cotrix.web.common.shared.ColumnSortInfo sortInfo, java.lang.String query, boolean force, AsyncCallback<org.cotrix.web.common.shared.DataWindow<org.cotrix.web.common.shared.codelist.UICodelist>> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getReportLogs( com.google.gwt.view.client.Range range, AsyncCallback<org.cotrix.web.common.shared.DataWindow<org.cotrix.web.common.shared.ReportLog>> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getMetadata( java.lang.String codelistId, AsyncCallback<org.cotrix.web.common.shared.codelist.UICodelistMetadata> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getCsvWriterConfiguration( java.lang.String codelistid, AsyncCallback<org.cotrix.web.common.shared.CsvConfiguration> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getMappings( java.lang.String codelistId, org.cotrix.web.publish.shared.Destination destination, org.cotrix.web.common.shared.Format type, AsyncCallback<org.cotrix.web.publish.shared.AttributesMappings> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void startPublish( org.cotrix.web.publish.shared.PublishDirectives publishDirectives, AsyncCallback<Void> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getPublishProgress( AsyncCallback<org.cotrix.web.common.shared.Progress> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getRepositories( com.google.gwt.view.client.Range range, org.cotrix.web.common.shared.ColumnSortInfo sortInfo, java.lang.String query, boolean force, AsyncCallback<org.cotrix.web.common.shared.DataWindow<org.cotrix.web.publish.shared.UIRepository>> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getRepositoryDetails( org.cotrix.web.common.shared.codelist.UIQName repositoryId, AsyncCallback<org.cotrix.web.common.shared.codelist.RepositoryDetails> callback );


    /**
     * Utility class to get the RPC Async interface from client-side code
     */
    public static final class Util 
    { 
        private static PublishServiceAsync instance;

        public static final PublishServiceAsync getInstance()
        {
            if ( instance == null )
            {
                instance = (PublishServiceAsync) GWT.create( PublishService.class );
            }
            return instance;
        }

        private Util()
        {
            // Utility class should not be instanciated
        }
    }
}

==> cotrix-web-publish-0.3.0-20160727.140620-117.jar: org/cotrix/web/publish/client/PublishServiceAsync.java <==
package org.cotrix.web.publish.client;

import com.google.gwt.core.client.GWT;
import com.google.gwt.user.client.rpc.AsyncCallback;

public interface PublishServiceAsync
{

    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getCodelists( com.google.gwt.view.client.Range range, org.cotrix.web.common.shared.ColumnSortInfo sortInfo, java.lang.String query, boolean force, AsyncCallback<org.cotrix.web.common.shared.DataWindow<org.cotrix.web.common.shared.codelist.UICodelist>> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getReportLogs( com.google.gwt.view.client.Range range, AsyncCallback<org.cotrix.web.common.shared.DataWindow<org.cotrix.web.common.shared.ReportLog>> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getMetadata( java.lang.String codelistId, AsyncCallback<org.cotrix.web.common.shared.codelist.UICodelistMetadata> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getCsvWriterConfiguration( java.lang.String codelistid, AsyncCallback<org.cotrix.web.common.shared.CsvConfiguration> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getMappings( java.lang.String codelistId, org.cotrix.web.publish.shared.Destination destination, org.cotrix.web.common.shared.Format type, AsyncCallback<org.cotrix.web.publish.shared.DefinitionsMappings> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void startPublish( org.cotrix.web.publish.shared.PublishDirectives publishDirectives, AsyncCallback<Void> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getPublishProgress( AsyncCallback<org.cotrix.web.publish.shared.PublishProgress> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getRepositories( com.google.gwt.view.client.Range range, org.cotrix.web.common.shared.ColumnSortInfo sortInfo, java.lang.String query, boolean force, AsyncCallback<org.cotrix.web.common.shared.DataWindow<org.cotrix.web.publish.shared.UIRepository>> callback );


    /**
     * GWT-RPC service  asynchronous (client-side) interface
     * @see org.cotrix.web.publish.client.PublishService
     */
    void getRepositoryDetails( org.cotrix.web.common.shared.codelist.UIQName repositoryId, AsyncCallback<org.cotrix.web.common.shared.codelist.RepositoryDetails> callback );


    /**
     * Utility class to get the RPC Async interface from client-side code
     */
    public static final class Util 
    { 
        private static PublishServiceAsync instance;

        public static final PublishServiceAsync getInstance()
        {
            if ( instance == null )
            {
                instance = (PublishServiceAsync) GWT.create( PublishService.class );
            }
            return instance;
        }

        private Util()
        {
            // Utility class should not be instanciated
        }
    }
}
